@@ -102,8 +102,6 @@ static void apply_pci_quirks(const struct pci_info *pci, int *irq_class)
 				break;
 		}
 	}
-
-	return;
 }
 
 /* Determin IRQ class based on PCI class code */
@@ -200,25 +198,30 @@ static unsigned int read_pci_data(const char *devpath, const char* file)
 /* Get pci information for IRQ classification */
 static int get_pci_info(const char *devpath, struct pci_info *pci)
 {
-	unsigned int data = PCI_INVAL_DATA;
+	unsigned int data;
 
-	if ((data = read_pci_data(devpath, "vendor")) == PCI_INVAL_DATA)
+	data = read_pci_data(devpath, "vendor");
+	if (data == PCI_INVAL_DATA)
 		return -ENODEV;
 	pci->vendor = (unsigned short)data;
 
-	if ((data = read_pci_data(devpath, "device")) == PCI_INVAL_DATA)
+	data = read_pci_data(devpath, "device");
+	if (data == PCI_INVAL_DATA)
 		return -ENODEV;
 	pci->device = (unsigned short)data;
 
-	if ((data = read_pci_data(devpath, "subsystem_vendor")) == PCI_INVAL_DATA)
+	data = read_pci_data(devpath, "subsystem_vendor");
+	if (data == PCI_INVAL_DATA)
 		return -ENODEV;
 	pci->sub_vendor = (unsigned short)data;
 
-	if ((data = read_pci_data(devpath, "subsystem_device")) == PCI_INVAL_DATA)
+	data = read_pci_data(devpath, "subsystem_device");
+	if (data == PCI_INVAL_DATA)
 		return -ENODEV;
 	pci->sub_device = (unsigned short)data;
 
-	if ((data = read_pci_data(devpath, "class")) == PCI_INVAL_DATA)
+	data = read_pci_data(devpath, "class");
+	if (data == PCI_INVAL_DATA)
 		return -ENODEV;
 	pci->class = data;
 
@@ -278,7 +281,6 @@ static void add_banned_irq(int irq, GList **list)
 
 	*list = g_list_append(*list, new);
 	log(TO_CONSOLE, LOG_INFO, "IRQ %d was BANNED.\n", irq);
-	return;
 }
 
 void add_cl_banned_irq(int irq)
@@ -290,8 +292,7 @@ gint substr_find(gconstpointer a, gconstpointer b)
 {
 	if (strstr(b, a))
 		return 0;
-	else
-		return 1;
+	return 1;
 }
 
 static void add_banned_module(char *modname, GList **modlist)
@@ -553,8 +554,7 @@ static int check_for_module_ban(char *name)
 
 	if (entry)
 		return 1;
-	else
-		return 0;
+	return 0;
 }
 
 static int check_for_irq_ban(struct irq_info *irq, char *mod)
@@ -883,6 +883,8 @@ static void remove_no_existing_irq(struct irq_info *info, void *data __attribute
 		entry = g_list_find_custom(info->assigned_obj->interrupts, info, compare_ints);
 	    if (entry) {
 			info->assigned_obj->interrupts = g_list_delete_link(info->assigned_obj->interrupts, entry);
+			/* Probe number of slots again, don't guess whether the IRQ left a free slot */
+			info->assigned_obj->slots_left = INT_MAX;
 		}
 	}
 	free_irq(info, NULL);
